//  TMSSBridge.h: Implementation of the TMSS Bridge, interface between MAC Scheduler and TMSS
//
//  Copyright (C) 2020
//  ASTRON (Netherlands Foundation for Research in Astronomy)
//  P.O.Box 2, 7990 AA Dwingeloo, The Netherlands, softwaresupport@astron.nl
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  $Id$

#ifndef TMSSBRIDGE_H
#define TMSSBRIDGE_H

#include <boost/date_time/posix_time/posix_time.hpp>
#include <jsoncpp/json/json.h>

namespace LOFAR {
	namespace MainCU {

using namespace boost::posix_time;
using namespace std;



class TMSSBridge
{
public:
    // Just creates an object and registers the connection parameters.
    TMSSBridge ();
    ~TMSSBridge ();

    vector<int> getSubTaskIDStartingInThreeMinutes(ptime currentTime, string clusterName);

    // Actually the next method is private, make it public to be able to use in UnitTest++
    vector<string> translateHttpResultToSortedUrlList(Json::Value result);
private:
    // Copying is not allowed
    TMSSBridge(const TMSSBridge&);
    TMSSBridge& operator=(const TMSSBridge&);

    // http request to TMSS
    Json::Value httpGET(const string& host, int const port, const string& target);

    string    itsUser;
    string    itsPassword;
    string    itsHost;
    int       itsPort;
};

  };//MainCU
};//LOFAR
#endif
