//  tTMSSBridge.cc: UnitTester of the TMSS Bridge, interface between MAC Scheduler and TMSS
//
//  Copyright (C) 2020
//  ASTRON (Netherlands Foundation for Research in Astronomy)
//  P.O.Box 2, 7990 AA Dwingeloo, The Netherlands, softwaresupport@astron.nl
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  $Id$
#include "UnitTest++/UnitTest++.h"


// The Subject to be Tested 
#include "../TMSSBridge.h"

#include <fstream>
#include <boost/property_tree/ptree.hpp>
#include <boost/property_tree/json_parser.hpp>
#include <jsonccp/json/json.h>


namespace pt = boost::property_tree;
using namespace std;

using namespace boost::property_tree;
using namespace LOFAR::MainCU;


Json::Value readFile(const std::string& jsonFile)
{
    ifstream ifs(jsonFile.c_str());
    if (!ifs) {
        throw runtime_error("Failed to open file " + jsonFile);
    }
    Json::Value jsonValue;
    try {
        ifs >> jsonValue;
    } catch(exception& e) {
        throw runtime_error("Error parsing file " + jsonFile + ":\n" + e.what());
    }
    return jsonValue;
 }



TEST(tmss_translate_http_result_ok)
{
    // check if json read goes well as precondition for the test
    //  See jsoncpp https://github.com/open-source-parsers/jsoncpp/wiki
    Json::Value jsonData(readFile("test_response.json"));

    int count = jsonData["count"];
    // check if count is equal to 4 .... otherwise precond test did not match so will make no sense to continue
    std::cout << count;
    TMSSBridge testTMSSBridge;

    // Read file json
    std::vector<string> testResult; 
    testResult = testTMSSBridge.translateHttpResultToSortedUrlList(jsonData);

    // Do some check like   CHECK_EQUAL
}


TEST(tmss_translate_http_empty_result)
{
    Json::Value jsonData("{}");
    TMSSBridge testTMSSBridge;

    // Read file json
    std::vector<string> testResult;
    testResult = testTMSSBridge.translateHttpResultToSortedUrlList(jsonData);

    // Do some check like   CHECK_EQUAL
}

int main(int, const char *[])
{
   return UnitTest::RunAllTests();
}
